@@ -2,7 +2,7 @@ package Bundle::CUFTS;
 
 use strict;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 =head1 NAME
 
@@ -22,6 +22,8 @@ Bundle::Catalyst
 
 Business::ISSN
 
+Catalyst::Plugin::FillInForm
+
 Class::Accessor
 
 Class::DBI
@@ -30,6 +32,8 @@ Class::DBI::AbstractSearch
 
 Class::DBI::Plugin::CountSearch
 
+Class::DBI::Plugin::Type
+
 Class::DBI::Sweet
 
 Date::Calc
@@ -42,6 +46,8 @@ Getopt::Long
 
 HTML::Entities
 
+HTML::FillInForm
+
 LWP::UserAgent
 
 MARC::Record
@@ -50,8 +56,14 @@ MIME::Lite
 
 Net::SMTP
 
+Perl6::Export::Attrs
+
+Pod::Escapes
+
 SQL::Abstract
 
+String::Approx
+
 Template
 
 Term::Readline
@@ -60,6 +72,8 @@ Text::CSV
 
 URI::Escape
 
+URI::OpenURL
+
 =head1 AUTHOR
 
 Todd Holbrook, C<tholbroo@sfu.ca>
